##  Before You Start
  * In this guide, we provide examples for the fundamental combinations of existing parameters.
  * Example queries are basic. They do not contain separate GraphQL variables or pagination parameters. To learn how to work with GraphQL queries and mutations, see [GraphQL Basics](https://help.sap.com/docs/leanix/ea/graphql-basics?locale=en-US&state=PRODUCTION&version=CLOUD "Learn the GraphQL basics. Create and execute your first queries and mutations.").
  * All examples are based on the fact sheet type Application. If you want to use a different fact sheet type, change the corresponding field.
  * All queries include placeholders for variables, such as {id} or {toId}. Before you make API requests, replace them with actual values.
  * You can use the [GraphiQL tool](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a6d497a4410149a8bffcc34da11b9__graphiql_tool) in your workspace to try out the provided examples. To open the tool, on the help menu, select Developer Tools > GraphQL Editor.
  * The examples usually contain simple queries that do not include all possible parameters. If needed, you can include additional parameters in the query.
  * Following GraphQL best practices, we recommend that you query minimal data to reduce the payload size and response times. For other recommendations, see [Best Practices](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a6d497a4410149a8bffcc34da11b9__best_practices).
